@@ -1,7 +1,7 @@
 /*
   This is the machine-specific part for the AMD64 (ne x86-64) architecture.
 
-  Copyright (C) 1995,1996,1997,1998,2000,2003,2004,2005,2006,2007,2008 Free Software Foundation, Inc.
+  Copyright (C) 1995,1996,1997,1998,2000,2003,2004,2005,2006,2007,2008,2011,2013,2014,2015 Free Software Foundation, Inc.
 
   This file is part of Gforth.
 
@@ -86,15 +86,20 @@ explicit register allocation and efforts to stop coalescing.
 */
 
 #if defined(FORCE_REG) && !defined(DOUBLY_INDIRECT) && !defined(VM_PROFILING)
+/* tested with gcc 4.4, 4.6, 4.7, 4.8, 5.2 */
 #define RPREG asm("%r13")
 #define FPREG asm("%r12")
 #define TOSREG asm("%r14")
-#define SPREG asm("%r15")
-#define IPREG asm("%rbx")
-#if 0
-#define LPREG asm("%rbp") /* doesn't work now */
+# define SPREG asm("%r15")
+# define IPREG asm("%rbx")
+#if ((__GNUC__==4 && defined(__GNUC_MINOR__) && __GNUC_MINOR__>=6) || (__GNUC__>=5))
+#define LPREG asm("%rbp") /* inefficient wit gcc-4.4 */
+#endif
+#define FTOSREG asm("%xmm15")
+#ifdef __clang__
+/* maybe we need some other options for clang */
+/* but so far, clang doesn't support manual register allocation */
 #endif
-#define FTOSREG asm("%xmm8")
 #endif
 
 #define GOTO_ALIGN asm(".p2align 4,,7");
