@@ -427,18 +427,6 @@ Label *gforth_engine(Xt *ip0 sr_proto)
 #endif
 #ifdef CPU_DEP2
   CPU_DEP2
-#endif
-#if defined(DIRECT_THREADED)
-Cell trampoline = (Cell)&&I_lp_trampoline;
-#else
-# if defined(DOUBLY_INDIRECT)
-const static Cell* trampoline0 = (Cell*)&&I_lp_trampoline;
-const static Cell* trampoline1 = (Cell*)&trampoline0;
-Cell trampoline = (Cell)&trampoline1;
-# else // indirect
-const static Cell* trampoline0 = (Cell*)&&I_lp_trampoline;
-Cell trampoline = (Cell)&trampoline0;
-# endif
 #endif
 
   rp = SPs->rpx;
