@@ -118,9 +118,8 @@ extern void* (*realloc_l)(void* addr, size_t size);
 #define DOABICODE	8
 #define DOSEMIABICODE   9
 #define DOEXTRA	10
-#define DOCOLLOC 11
-#define DODOESXT 12
-#define DOER_MAX        12
+#define DODOESXT 11
+#define DOER_MAX        11
 
 #include "machine.h"
 
@@ -455,7 +454,6 @@ Label *gforth_engine(Xt *ip sr_proto);
 Label *gforth_engine2(Xt *ip sr_proto);
 Label *gforth_engine3(Xt *ip sr_proto);
 
-
 Cell gforth_main(int argc, char **argv, char **env);
 int gforth_args(int argc, char ** argv, char ** path, char ** imagename);
 ImageHeader* gforth_loader(char* imagename, char* path);
@@ -646,9 +644,6 @@ void zexpand(char * zfile);
 #ifdef HAVE_ENDIAN_H
 #include <endian.h>
 #else
-#define BSWAP16(x) ((((x) >> 8) & 0xff | (((x) & 0xff) << 8)))
-#define BSWAP32(x) ((BSWAP16((x) >> 16) | (BSWAP16(x) << 16)))
-#define BSWAP64(x) ((BSWAP32((x) >> 32) | (BSWAP32(x) << 32)))
 #ifdef WORDS_BIGENDIAN
 #define htobe16(x) (x)
 #define htobe32(x) (x)
