@@ -401,7 +401,6 @@ void gforth_relocate(Cell *image, const Char *bitstring,
 	    case CF(DOABICODE) :
 	    case CF(DOSEMIABICODE): 
 	    case CF(DOEXTRA): 
-	    case CF(DOCOLLOC): 
 	    case CF(DODOESXT): 
 	      MAKE_CF(image+i,symbols[CF(token)]); break;
 #endif /* !defined(DOUBLY_INDIRECT) */
@@ -599,8 +598,8 @@ static void *dict_alloc_read(FILE *file, Cell imagesize, Cell dictsize, Cell off
   if (offset==0) {
     image=alloc_mmap(dictsize);
     if (image != (void *)MAP_FAILED) {
-      debugp(stderr, "mmap($%lx) succeeds, address=%p\n", (long)dictsize, image);
       void *image1;
+      debugp(stderr, "mmap($%lx) succeeds, address=%p\n", (long)dictsize, image);
       debugp(stderr,"try mmap(%p, $%lx, ..., MAP_FIXED|MAP_FILE, imagefile, 0); ", image, imagesize);
       image1 = mmap(image, imagesize, PROT_EXEC|PROT_READ|PROT_WRITE, MAP_FIXED|MAP_FILE|MAP_PRIVATE|map_noreserve, fileno(file), 0);
       after_alloc(image1,dictsize);
@@ -1192,7 +1191,8 @@ static void reserve_code_super(PrimNum origs[], int ninsts)
       if (i>0)
         size += priminfos[origs[i-1]].restlength+goto_len+CODE_ALIGNMENT-1;
   }
-  size += priminfos[origs[i-1]].restlength+goto_len;
+  if (i>0)
+    size += priminfos[origs[i-1]].restlength+goto_len;
   reserve_code_space(size);
 }
 #endif
@@ -2212,10 +2212,13 @@ enum {
 static void print_diag()
 {
 
-#if !defined(HAVE_GETRUSAGE)
+#if !defined(HAVE_GETRUSAGE) || !defined(HAS_ATOMIC)
   fprintf(stderr, "*** missing functionality ***\n"
 #ifndef HAVE_GETRUSAGE
 	  "    no getrusage -> CPUTIME broken\n"
+#endif
+#ifndef HAS_ATOMIC
+	  "    no atomic operations -> !@ and co. broken\n"
 #endif
 	  );
 #endif
@@ -2356,7 +2359,7 @@ int gforth_args(int argc, char ** argv, char ** path, char ** imagename)
     case 'x': debug = 1; break;
     case 'D': print_diag(); break;
     case 'v': fputs(PACKAGE_STRING" "ARCH"\n", stderr); return 1;
-    case opt_code_block_size: code_area_size = atoi(optarg); break;
+    case opt_code_block_size: if((code_area_size = convsize(optarg,sizeof(Char)))==-1L) return 1; break;
     case ss_number: static_super_number = atoi(optarg); break;
     case ss_states: maxstates = max(min(atoi(optarg),MAX_STATE),1); break;
 #ifndef NO_DYNAMIC
