@@ -62,6 +62,9 @@ ChangesEnvironment=yes
 OutputBaseFilename=gforth$SF-$VERSION
 AppPublisher=Free Software Foundation, Gforth team
 AppPublisherURL=http://bernd-paysan.de/gforth.html
+SignTool=signtool sign /fd SHA256 /tr http://timestamp.comodoca.com/authenticode /td SHA256 \$f
+SetupIconFile=gforth.ico
+UninstallDisplayIcon={app}\\gforth.ico
 
 [Messages]
 WizardInfoBefore=License Agreement
@@ -88,7 +91,7 @@ Name: "{app}\\doc\\gforth"
 Name: "{app}\\doc\\vmgen"
 Name: "{app}\\lib\\gforth\\$VERSION\\$machine\\libcc-named"
 Name: "{app}\\include\\gforth\\$VERSION"
-Name: "{app}\\..\bin"
+Name: "{app}\\..\\bin"
 Name: "{app}\\..\\tmp"; Permissions: users-modify
 
 [Files]
@@ -123,6 +126,12 @@ else
     cat <<EOF
 Source: "c:\\$CYGWIN\\bin\\sh.exe"; DestDir: "{app}\\..\\bin"
 Source: "c:\\$CYGWIN\\bin\\cygwin-console-helper.exe"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cygwin1.dll"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cyggcc_s-1.dll"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cygintl-8.dll"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cygiconv-2.dll"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cygreadline7.dll"; DestDir: "{app}\\..\\bin"
+Source: "c:\\$CYGWIN\\bin\\cygncursesw-10.dll"; DestDir: "{app}\\..\\bin"
 Source: "c:\\$CYGWIN\\bin\\cyggcc_s-1.dll"; DestDir: "{app}"
 Source: "c:\\$CYGWIN\\bin\\cygwin1.dll"; DestDir: "{app}"
 Source: "c:\\$CYGWIN\\bin\\cygintl-8.dll"; DestDir: "{app}"
